OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Innebygd melding %s",
    "Important mail" : "Viktig e-post",
    "No message found yet" : "Ingen meldinger funnet enda",
    "Set up an account" : "Sett opp en konto",
    "Unread mail" : "Ulest e-post",
    "Important" : "Viktig",
    "Work" : "Arbeid",
    "Personal" : "Personlig",
    "To Do" : "Gjøremål",
    "Later" : "Senere",
    "Mail" : "E-post",
    "You are reaching your mailbox quota limit for {account_email}" : "Du når grensen for postbokskvote for {account_email}",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Du bruker for øyeblikket {percentage} av postbokslagringen. Vennligst lag litt plass ved å slette unødvendige e-poster.",
    "Mails" : "E-post",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following email: %3$s" : "Avsender e-post: %1$s er ikke i adresseboken, men avsendernavnet: %2$s er i adresseboken med følgende e-post: %3$s",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following emails: %3$s" : "Avsender e-post: %1$s er ikke i adresseboken, men avsendernavnet: %2$s er i adresseboken med følgende e-poster: %3$s",
    "Sender is using a custom email: %1$s instead of the sender email: %2$s" : "Avsender bruker en egendefinert e-postadresse: %1$s i stedet for avsenderens e-postadresse: %2$s",
    "Sent date is in the future" : "Sendt dato er i fremtiden",
    "Some addresses in this message are not matching the link text" : "Noen adresser i denne meldingen samsvarer ikke med lenketeksten",
    "Reply-To email: %1$s  is different from the sender email: %2$s" : "Svar på e-post: %1$s er forskjellig fra avsenderens e-post: %2$s",
    "💌 A mail app for Nextcloud" : "💌 En e-postapp for Nextcloud",
    "Your session has expired. The page will be reloaded." : "Økten din er utløpt. Siden lastes inn på nytt.",
    "Drafts are saved in:" : "Utkast lagres i:",
    "Sent messages are saved in:" : "Sendte meldinger lagres i:",
    "Deleted messages are moved in:" : "Slettede meldinger flyttes til:",
    "Archived messages are moved in:" : "Arkiverte meldinger flyttes til:",
    "Snoozed messages are moved in:" : "Utsatte meldinger flyttes til:",
    "Junk messages are saved in:" : "Søppelpostmeldinger lagres i:",
    "Connecting" : "Kobler til",
    "Reconnect Google account" : "Koble til Google-kontoen på nytt",
    "Sign in with Google" : "Logg på med Google",
    "Reconnect Microsoft account" : "Koble til Microsoft-kontoen på nytt",
    "Sign in with Microsoft" : "Logg på med Microsoft",
    "Save" : "Lagre",
    "Connect" : "Koble til",
    "Looking up configuration" : "Slår opp konfigurasjonen",
    "Checking mail host connectivity" : "Sjekker e-postvertens tilkobling",
    "Configuration discovery failed. Please use the manual settings" : "Konfigurasjonsoppdagelse mislyktes. Vennligst bruk de manuelle innstillingene",
    "Password required" : "Passord kreves",
    "Testing authentication" : "Tester autentisering",
    "Awaiting user consent" : "Venter på brukersamtykke",
    "Account created. Please follow the pop-up instructions to link your Google account" : "Konto opprettet. Følg instruksjonene i sprettoppvinduet for å tilknytte Google-kontoen din.",
    "Account created. Please follow the pop-up instructions to link your Microsoft account" : "Konto opprettet. Følg sprettoppinstruksjonene for å koble Microsoft-kontoen din",
    "Loading account" : "Laster konto",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Kontoen er oppdatert. Følg instruksjonene i sprettoppvinduet for å koble til Google-kontoen din på nytt.",
    "Account updated. Please follow the pop-up instructions to reconnect your Microsoft account" : "Kontoen er oppdatert. Følg sprettoppinstruksjonene for å koble til Microsoft-kontoen på nytt",
    "Account updated" : "Konto oppdatert",
    "IMAP server is not reachable" : "IMAP-serveren er ikke tilgjengelig",
    "SMTP server is not reachable" : "SMTP-serveren er ikke tilgjengelig",
    "IMAP username or password is wrong" : "IMAP brukernavn eller passord er feil",
    "SMTP username or password is wrong" : "SMTP brukernavn eller passord er feil",
    "IMAP connection failed" : "IMAP tilkobling feilet",
    "SMTP connection failed" : "SMTP tilkobling feilet",
    "Authorization pop-up closed" : "Autorisasjons-sprettoppvinduet lukket",
    "Configuration discovery temporarily not available. Please try again later." : "Oppdagelse av konfigurasjon midlertidig ikke tilgjengelig. Vennligst forsøk igjen senere.",
    "There was an error while setting up your account" : "Det oppsto en feil under oppsett av kontoen din",
    "Auto" : "Auto",
    "Name" : "Navn",
    "Mail address" : "E-postadresse",
    "name@example.org" : "navn@eksempel.org",
    "Please enter an email of the format name@example.com" : "Skriv inn en e-post med formatet navn@eksempel.com",
    "Password" : "Passord",
    "Manual" : "Manuell",
    "IMAP Settings" : "IMAP-innstillinger",
    "IMAP Host" : "IMAP-server",
    "IMAP Security" : "IMAP-sikkerhet",
    "None" : "Ingen",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-port",
    "IMAP User" : "IMAP-bruker",
    "IMAP Password" : "IMAP-passord",
    "SMTP Settings" : "SMTP-innstillinger",
    "SMTP Host" : "SMTP-server",
    "SMTP Security" : "SMTP-sikkerhet",
    "SMTP Port" : "SMTP-port",
    "SMTP User" : "SMTP-bruker",
    "SMTP Password" : "SMTP-passord",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "For at Google-kontoen skal fungere med denne appen, må du aktivere tofaktorautentisering for Google og generere et app-passord.",
    "Account settings" : "Kontoinnstillinger",
    "Aliases" : "Aliaser",
    "Alias to S/MIME certificate mapping" : "Alias til S/MIME-sertifikattilordning",
    "Signature" : "Signatur",
    "A signature is added to the text of new messages and replies." : "En signatur legges til teksten til nye meldinger og svar.",
    "Writing mode" : "Skrivemodus",
    "Preferred writing mode for new messages and replies." : "Foretrukket skrivemodus for nye meldinger og svar.",
    "Default folders" : "Standardmapper",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "Mappene som skal brukes til utkast, sendte meldinger, slettede meldinger, arkiverte meldinger og søppelpost.",
    "Automatic trash deletion" : "Automatisk sletting av papirkurven",
    "Days after which messages in Trash will automatically be deleted:" : "Dager etter hvilke meldinger i papirkurven automatisk blir slettet:",
    "Autoresponder" : "Automatisk svartjeneste",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatisk svar på innkommende meldinger. Hvis noen sender deg flere meldinger, vil dette automatiserte svaret bli sendt maksimalt en gang hver 4. dag.",
    "Filters" : "Filtere",
    "Mail server" : "E-postserver",
    "Update alias" : "Oppdater alias",
    "Rename alias" : "Gi alias nytt navn",
    "Show update alias form" : "Vis skjema for alias oppdatering",
    "Delete alias" : "Slett alias",
    "Go back" : "Gå tilbake",
    "Change name" : "Bytt navn",
    "Email address" : "E-post adresse",
    "Add alias" : "Legg til alias",
    "Create alias" : "Opprett alias",
    "Cancel" : "Avbryt",
    "Activate" : "Aktiver",
    "Remind about messages that require a reply but received none" : "Påminnelse om meldinger som krever svar, men ikke har mottatt noen",
    "Could not update preference" : "Kunne ikke oppdatere preferanse",
    "Mail settings" : "E-post instillinger",
    "General" : "Generell",
    "Add mail account" : "Legg til e-postkonto",
    "Appearance" : "Utseende",
    "Layout" : "Utforming",
    "List" : "Liste",
    "Vertical split" : "Loddrett deling",
    "Horizontal split" : "Horisontal deling",
    "Sorting" : "Sorter",
    "Newest first" : "Nyeste først",
    "Oldest first" : "Eldste først",
    "Search in body" : "Søk i innholdstekst",
    "Gravatar settings" : "Gravatar-innstillinger",
    "Mailto" : "Mailto",
    "Register" : "Registrer",
    "Privacy and security" : "Personvern og sikkerhet",
    "Security" : "Sikkerhet",
    "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Fremhev eksterne e-postadresser ved å aktivere denne funksjonen, administrer dine interne adresser og domener for å sikre at gjenkjente kontakter forblir umerket.",
    "S/MIME" : "S/MIME",
    "Manage certificates" : "Administrer sertifikat",
    "Mailvelope" : "Mailvelope",
    "Assistance features" : "Assistanse funksjoner",
    "About" : "Om",
    "Keyboard shortcuts" : "Tastatursnarveier",
    "Compose new message" : "Lag ny melding",
    "Newer message" : "Nyere melding",
    "Older message" : "Eldre melding",
    "Toggle star" : "Merk med stjerne",
    "Toggle unread" : "Merk som ulest",
    "Archive" : "Arkiv",
    "Delete" : "Slett",
    "Search" : "Søk",
    "Send" : "Send",
    "Refresh" : "Oppdater",
    "Ok" : "Ok",
    "No certificate" : "Ingen sertifikat",
    "Certificate updated" : "Sertifikat oppdatert",
    "Could not update certificate" : "Kunne ikke oppdatere sertifikatet",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - Gyldig til {expiryDate}",
    "Select an alias" : "Velg et alias",
    "Select certificates" : "Velg sertifikater",
    "Update Certificate" : "Oppdater sertifikat",
    "The selected certificate is not trusted by the server. Recipients might not be able to verify your signature." : "Det valgte sertifikatet er ikke klarert av serveren. Mottakerne kan kanskje ikke bekrefte signaturen din.",
    "Encrypt with S/MIME and send later" : "Krypter med S/MIME og send senere",
    "Encrypt with S/MIME and send" : "Krypter med S/MIME og send",
    "Encrypt with Mailvelope and send later" : "Krypter med Mailvelope og send senere",
    "Encrypt with Mailvelope and send" : "Krypter med Mailvelope og send",
    "Send later" : "Send senere",
    "Message {id} could not be found" : "Meldingen {id} ble ikke funnet",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Signer eller krypter med S/MIME ble valgt, men vi har ikke et sertifikat for det valgte aliaset. Meldingen blir ikke signert eller kryptert.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "All eksisterende formatering (for eksempel fet, kursiv, understreket eller innebygde bilder) fjernes.",
    "Turn off formatting" : "Slå av formatering",
    "Turn off and remove formatting" : "Slå av og fjern formatering",
    "Keep formatting" : "Behold formatering",
    "From" : "Fra",
    "Select account" : "Velg konto",
    "To" : "Til",
    "Cc/Bcc" : "Kopi/Blindkopi",
    "Select recipient" : "Velg mottaker",
    "Contact or email address …" : "Kontakt eller e-post adresse ...",
    "Cc" : "Kopi",
    "Bcc" : "Blindkopi",
    "Subject" : "Emne",
    "Subject …" : "Emne ...",
    "This message came from a noreply address so your reply will probably not be read." : "Denne meldingen kom fra en noreply-adresse, så svaret ditt vil sannsynligvis ikke bli lest.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Følgende mottakere har ikke et S/MIME-sertifikat: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "Følgende mottakere har ikke en PGP-nøkkel: {recipients}.",
    "Write message …" : "Skriv melding ...",
    "Saving draft …" : "Lagrer kladd…",
    "Error saving draft" : "Feil under lagring av utkast",
    "Draft saved" : "Kladd ble lagret",
    "Save draft" : "Lagre utkast",
    "Discard & close draft" : "Kast og lukk utkast",
    "Enable formatting" : "Aktiver formatering",
    "Disable formatting" : "Deaktiver formatering",
    "Upload attachment" : "Last opp vedlegg",
    "Add attachment from Files" : "Legg til vedlegg fra Filer",
    "Add share link from Files" : "Legg til delingskobling fra Filer",
    "Smart picker" : "Smartvelger",
    "Request a read receipt" : "Be om lesekvittering",
    "Sign message with S/MIME" : "Signer melding med S/MIME",
    "Encrypt message with S/MIME" : "Krypter melding med S/MIME",
    "Encrypt message with Mailvelope" : "Krypter melding med Mailvelope",
    "Send now" : "Send nå",
    "Tomorrow morning" : "I morgen tidlig",
    "Tomorrow afternoon" : "I morgen ettermiddag",
    "Monday morning" : "Mandag morgen",
    "Custom date and time" : "Egendefinert dato og klokkeslett",
    "Enter a date" : "Skriv inn dato",
    "Choose" : "Velg",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Vedlegget overskrider den tillatte vedleggsstørrelsen på {size}. Vennligst del filen via lenke i stedet.","Vedleggene overskrider den tillatte vedleggsstørrelsen på {size}. Vennligst del filene via lenke i stedet."],
    "Choose a file to add as attachment" : "Velg en fil å legge til som vedlegg",
    "Choose a file to share as a link" : "Velg en fil du vil dele som en lenke",
    "_{count} attachment_::_{count} attachments_" : ["{count} vedlegg","{count} vedlegg"],
    "Untitled message" : "Melding uten navn",
    "Expand composer" : "Utvid skrivebehandler",
    "Close composer" : "Lukk skrivebehandler",
    "Confirm" : "Bekreft",
    "Tag: {name} deleted" : "Merke: {name} slettet",
    "An error occurred, unable to delete the tag." : "En feil oppstod, ikke i stand til å slette merkelappen.",
    "The tag will be deleted from all messages." : "Merkelappen slettes fra alle meldinger.",
    "Plain text" : "Ren tekst",
    "Rich text" : "Rik tekst",
    "No messages in this folder" : "Ingen meldinger i denne mappen",
    "No messages" : "Ingen meldinger",
    "Blind copy recipients only" : "Kun blind kopi mottakere",
    "No subject" : "Ingen emne",
    "Later today – {timeLocale}" : "Senere i dag – {timeLocale}",
    "Set reminder for later today" : "Sett påminnelse til senere i dag",
    "Tomorrow – {timeLocale}" : "I morgen – {timeLocale}",
    "Set reminder for tomorrow" : "Sett påminnelse for i morgen",
    "This weekend – {timeLocale}" : "Denne helgen – {timeLocale}",
    "Set reminder for this weekend" : "Sett påminnelse for denne helgen",
    "Next week – {timeLocale}" : "Neste uke – {timeLocale}",
    "Set reminder for next week" : "Sett påminnelse for neste uke",
    "Could not delete message" : "Kunne ikke slette melding",
    "Could not archive message" : "Kunne ikke arkivere melding",
    "Thread was snoozed" : "Tråden ble slumret",
    "Could not snooze thread" : "Kunne ikke slumre tråd",
    "Thread was unsnoozed" : "Tråden fikk opphevet slumringen",
    "Could not unsnooze thread" : "Kunne ikke oppheve slumring",
    "Encrypted message" : "Kryptert melding",
    "This message is unread" : "Meldingen er ulest",
    "Unfavorite" : "Fjern favorittmarkering",
    "Favorite" : "Favoritt",
    "Unread" : "Ulest",
    "Read" : "Les",
    "Unimportant" : "Uviktig",
    "Mark not spam" : "Merk som ikke søppelpost",
    "Mark as spam" : "Merk som søppelpost",
    "Edit tags" : "Rediger merkelapper",
    "Snooze" : "Slumre",
    "Unsnooze" : "Opphev slumring",
    "Move thread" : "Flytt tråden",
    "Archive thread" : "Arkiver tråd",
    "Archive message" : "Arkiver melding",
    "Delete thread" : "Slett tråden",
    "Delete message" : "Slett melding",
    "More actions" : "Flere handlinger",
    "Back" : "Tilbake",
    "Set custom snooze" : "Angi tilpasset slumring",
    "Edit as new message" : "Rediger som ny melding",
    "Create task" : "Opprett oppgave",
    "Download message" : "Last ned melding",
    "Load more" : "Last mer",
    "_Mark {number} read_::_Mark {number} read_" : ["Merk {number} som lest","Merk {number} som leste"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Merk {number} som ulest","Merk {number} som uleste"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Merk {number} som viktig","Merk {number} som viktige"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Merk {number} som uviktig","Merk {number} som uviktige"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Fjern {number} som favoritt","Fjern {number} som favoritter"],
    "_Favorite {number}_::_Favorite {number}_" : ["Favoritt {number}","Favoritt {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["Fjern markeringen av {number}","Fjern markeringen av {number}"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Marker {number} som søppelpost","Marker {number} som søppelpost"],
    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["Marker {number} som ikke søppelpost","Marker {number} som ikke søppelpost"],
    "_Edit tags for {number}_::_Edit tags for {number}_" : ["Rediger merkelapp for {number}","Rediger merkelapper for {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["Flytt {number} tråd","Flytt {number} tråder"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Videresend {number} som vedlegg","Videresend {number} som vedlegg"],
    "Mark as unread" : "Merk som ulest",
    "Mark as read" : "Merk som lest",
    "Mark as important" : "Merk som viktig",
    "Report this bug" : "Rapporter denne feilen",
    "Event created" : "Hendelse opprettet",
    "Could not create event" : "Kunne ikke opprette hendelsen",
    "Create event" : "Opprettet hendelse",
    "All day" : "Hele dagen",
    "Attendees" : "Deltakere",
    "Select calendar" : "Velg kalender",
    "Description" : "Beskrivelse",
    "Create" : "Opprett",
    "This event was updated" : "Denne hendelsen ble oppdatert",
    "{attendeeName} accepted your invitation" : "{attendeeName} godtok invitasjonen",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} godtok foreløpig invitasjonen",
    "{attendeeName} declined your invitation" : "{attendeeName} avviste invitasjonen",
    "{attendeeName} reacted to your invitation" : "{attendeeName} reagerte på invitasjonen",
    "Failed to save your participation status" : "Kan ikke lagre deltakelsesstatusen",
    "You accepted this invitation" : "Du godtok denne invitasjonen",
    "You tentatively accepted this invitation" : "Du foreløpig akseptere denne invitasjonen",
    "You declined this invitation" : "Du avviste denne invitasjonen",
    "You already reacted to this invitation" : "Du reagerte allerede på denne invitasjonen",
    "You have been invited to an event" : "Du har blitt invitert til en hendelsen",
    "This event was cancelled" : "Denne hendelsen ble kansellert",
    "Save to" : "Lagre til",
    "Select" : "Velg",
    "Comment" : "Kommentar",
    "Accept" : "Aksepter",
    "Decline" : "Avslå",
    "Tentatively accept" : "Foreløpig akseptert",
    "More options" : "Mer innstillinger",
    "Could not remove internal address {sender}" : "Kunne ikke fjerne intern adresse {sender}",
    "Could not add internal address {address}" : "Kan ikke legge til intern adresse {address}",
    "individual" : "individuell",
    "domain" : "domene",
    "Remove" : "Fjern",
    "email" : "e-post",
    "Add internal address" : "Legg til intern adresse",
    "Add internal email or domain" : "Legg til intern e-post eller domene",
    "Itinerary for {type} is not supported yet" : "Reiserute for {type} støttes ikke ennå",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Du har ikke lov til å flytte denne meldingen til arkivmappen og/eller slette denne meldingen fra gjeldende mappe",
    "Last hour" : "Siste time",
    "Today" : "I dag",
    "Yesterday" : "Igår",
    "Last week" : "Forrige uke",
    "Last month" : "Forrige måned",
    "Loading messages …" : "Laster meldinger ...",
    "Choose target folder" : "Velg målmappe",
    "No more submailboxes in here" : "Ingen flere underpostbokser her",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Meldinger blir automatisk merket som viktige basert på hvilke meldinger du har interagert med eller merket som viktige. I begynnelsen må du kanskje endre viktigheten manuelt for å lære systemet, men det vil forbedres over tid.",
    "Messages sent by you that require a reply but did not receive one after a couple of days will be shown here." : "Meldinger sendt av deg som krever svar, men ikke mottok en etter et par dager, vises her.",
    "Follow up" : "Følg opp",
    "Follow up info" : "Følg opp info",
    "Important info" : "Viktig informasjon",
    "Other" : "Annet",
    "Could not send mdn" : "Kunne ikke sende mdn",
    "The sender of this message has asked to be notified when you read this message." : "Avsenderen av denne meldingen har bedt om å bli varslet når du leser denne meldingen.",
    "Notify the sender" : "Gi beskjed til avsender",
    "You sent a read confirmation to the sender of this message." : "Du sendte en lesebekreftelse til avsenderen av denne meldingen.",
    "Message was snoozed" : "Meldingen ble slumret",
    "Could not snooze message" : "Kunne ikke slumre melding",
    "Message was unsnoozed" : "Melding ble ikke slumret",
    "Could not unsnooze message" : "Kunne ikke oppheve meldingsslumring",
    "Forward" : "Fremover",
    "Move message" : "Flytt melding",
    "Translate" : "Oversette",
    "Forward message as attachment" : "Videresend melding som et vedlegg",
    "View source" : "Vis kilde",
    "Print message" : "Skriv ut melding",
    "Download thread data for debugging" : "Last ned tråddata for feilsøking",
    "Message body" : "Meldingstekst",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Advarsel: S/MIME-signaturen til denne meldingen er ikke bekreftet. Avsenderen kan utgi seg for å være noen!",
    "Unnamed" : "Uten navn",
    "Embedded message" : "Innebygd melding",
    "Attachment saved to Files" : "Vedlegget ble lagret i Filer",
    "Attachment could not be saved" : "Vedlegget kunne ikke lagres",
    "calendar imported" : "Kalender importert",
    "Choose a folder to store the attachment in" : "Velg en mappe å lagre vedlegget i",
    "Import into calendar" : "Importer til kalender",
    "Download attachment" : "Last ned vedlegg",
    "Save to Files" : "Lagre i Filer",
    "Attachments saved to Files" : "Vedleggene ble lagret i Filer",
    "Error while saving attachments" : "Feil under lagring av vedlegg",
    "View fewer attachments" : "Se færre vedlegg",
    "Choose a folder to store the attachments in" : "Velg en mappe å lagre vedleggene i",
    "Save all to Files" : "Lagre alle i Filer",
    "Download Zip" : "Last ned zip",
    "_View {count} more attachment_::_View {count} more attachments_" : ["Se {count} vedlegg til","Se {count} flere vedlegg"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Denne meldingen er kryptert med PGP. Installer Mailvelope for å dekryptere den.",
    "The images have been blocked to protect your privacy." : "Bildene har blitt blokkert for å beskytte privatlivet.",
    "Show images" : "Vis bilder",
    "Show images temporarily" : "Vis bilder midlertidig",
    "Always show images from {sender}" : "Vis alltid bilder fra {sender}",
    "Always show images from {domain}" : "Vis alltid bilder fra {domain}",
    "Message frame" : "Meldingsramme",
    "Quoted text" : "Sitert tekst",
    "Move" : "Flytt",
    "Moving" : "Flytter",
    "Moving thread" : "Flytter tråd",
    "Moving message" : "Flytter melding",
    "Remove account" : "Fjern konto",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Kontoen for {email} og bufrede e-postdata vil bli fjernet fra Nextcloud, men ikke fra e-postleverandøren din.",
    "Remove {email}" : "Fjern {email}",
    "Provisioned account is disabled" : "Klargjort konto er deaktivert",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Vennligst logg inn med et passord for å aktivere denne kontoen. Den nåværende økten bruker passordløs autentisering, for eksempel SSO eller WebAuthn.",
    "Add folder" : "Legg til mappe",
    "Folder name" : "Mappenavn",
    "Saving" : "Lagrer",
    "Move up" : "Flytt opp",
    "Move down" : "Flytt ned",
    "Show all folders" : "Vis alle mapper",
    "Collapse folders" : "Skjul mapper",
    "_{total} message_::_{total} messages_" : ["{total} melding","{total} meldinger"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ulest av {total}","{unread} uleste av {total}"],
    "Loading …" : "Laster...",
    "All messages in mailbox will be deleted." : "Alle meldinger i postkassen blir slettet.",
    "Clear mailbox {name}" : "Tøm postboks {name}",
    "Delete folder" : "Slett mappe",
    "An error occurred, unable to rename the mailbox." : "Det oppsto en feil, kan ikke gi nytt navn til postboks.",
    "Mark all as read" : "Marker alle som lest",
    "Rename" : "Endre navn",
    "Move folder" : "Flytt mappe",
    "Clear cache" : "Tøm hurtiglager",
    "Clear locally cached data, in case there are issues with synchronization." : "Slett lokalt bufrede data, i tilfelle det er problemer med synkronisering.",
    "Subscribed" : "Abonnerer",
    "Sync in background" : "Synkroniser i bakgrunnen",
    "Outbox" : "Utboks",
    "New message" : "Ny melding",
    "Edit message" : "Rediger melding",
    "Draft" : "Kladd",
    "Reply" : "Svar",
    "Message saved" : "Melding lagret",
    "Failed to save message" : "Lagring av melding feilet",
    "Failed to save draft" : "Lagring av utkast feilet",
    "attachment" : "vedlegg",
    "attached" : "vedlagt",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Du prøver å sende til mange mottakere i Til og/eller Kopi. Vurder å bruke Blindkopi for å skjule mottakeradressene.",
    "You mentioned an attachment. Did you forget to add it?" : "Du nevnte et vedlegg. Glemte du å legge det ved?",
    "Message discarded" : "Meldingen forkastet",
    "Could not discard message" : "Kunne ikke forkaste meldingen",
    "Maximize composer" : "Maksimer skrivevindu",
    "Minimize composer" : "Minimer skrivevindu",
    "Error sending your message" : "Feil ved sending av meldingen din",
    "Retry" : "Prøv igjen",
    "Warning sending your message" : "Advarsel sender meldingen din",
    "Send anyway" : "Send likevel",
    "Autoresponder off" : "Autosvar av",
    "Autoresponder on" : "Autosvar på",
    "Autoresponder follows system settings" : "Autosvar følger systeminnstillingene",
    "The autoresponder follows your personal absence period settings." : "Den automatiske svartjenesten følger innstillingene for din personlige fraværsperiode.",
    "Edit absence settings" : "Rediger innstillinger for fravær",
    "First day" : "Første dag",
    "Last day (optional)" : "Siste dag (valgfritt)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} erstattes med emnet for meldingen du svarer på",
    "Message" : "Melding",
    "Oh Snap!" : "Oi!",
    "Save autoresponder" : "Lagre autosvar",
    "Could not open outbox" : "Kunne ikke åpne utboksen",
    "Pending or not sent messages will show up here" : "Ventende eller ikke sendte meldinger vises her",
    "Mail server error" : "Feil i e-postserveren",
    "Message could not be sent" : "Melding kunne ikke bli sendt",
    "Message deleted" : "Melding slettet",
    "Phishing email" : "Nettfisking e-post",
    "Hide suspicious links" : "Skjul mistenkelige koblinger",
    "Show suspicious links" : "Vis mistenkelige koblinger",
    "link text" : "Tekst på kobling",
    "Copied email address to clipboard" : "Kopierte e-postadressen til utklippstavlen",
    "Could not copy email address to clipboard" : "Kunne ikke kopiere e-postadressen til utklippstavlen",
    "Contacts with this address" : "Kontakter med denne adressen",
    "Add to Contact" : "Legg til kontakt",
    "New Contact" : "Ny kontakt",
    "Copy to clipboard" : "Kopiert til utklippstavlen",
    "Contact name …" : "Kontakt navn ...",
    "Add" : "Legg til",
    "Show less" : "Vis mindre",
    "Show more" : "Vis mer",
    "Clear" : "Tøm",
    "Close" : "Lukk",
    "Search parameters" : "Søkeparametere",
    "Search subject" : "Søk emne",
    "Body" : "Kropp",
    "Search body" : "Søk innholdstekst",
    "Date" : "Dato",
    "Pick a start date" : "Velg en startdato",
    "Pick an end date" : "Velg en sluttdato",
    "Select senders" : "Velg avsendere",
    "Select recipients" : "Velg mottakere",
    "Select CC recipients" : "Velg kopi-mottakere",
    "Select BCC recipients" : "Velg blind kopi-mottakere",
    "Tags" : "Merkelapper",
    "Select tags" : "Velg merkelapper",
    "Marked as" : "Merket som",
    "Has attachments" : "Har vedlegg",
    "Has attachment" : "Har vedlegg",
    "Last 7 days" : "Siste 7 dager",
    "From me" : "Fra meg",
    "Enable mail body search" : "Aktiver søk i meldingsinnhold for e-post",
    "Sieve host" : "Sieve-tjener",
    "Sieve security" : "Sieve-sikkerhet",
    "Sieve Port" : "Sieve port",
    "Sieve credentials" : "Sieve-legitimasjon",
    "IMAP credentials" : "IMAP-legitimasjon",
    "Custom" : "Egendefinert",
    "Sieve User" : "Sieve brukernavn",
    "Sieve Password" : "Sieve passord",
    "Oh snap!" : "Å knips!",
    "Save sieve settings" : "Lagre sieve innstillinger",
    "The syntax seems to be incorrect:" : "Syntaksen ser ut til å være feil:",
    "Save sieve script" : "Lagre sieve script",
    "Signature …" : "Signatur ...",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Signaturen din er større enn 2 MB. Dette kan påvirke ytelsen til redigeringsprogrammet ditt.",
    "Save signature" : "Lagre signatur",
    "Place signature above quoted text" : "Plasser signatur over sitert tekst",
    "Message source" : "Melding kilde",
    "An error occurred, unable to rename the tag." : "Det oppsto en feil, kan ikke gi nytt navn til taggen.",
    "Edit name or color" : "Rediger navn eller farge",
    "Saving new tag name …" : "Lagrer nytt tagnavn …",
    "Delete tag" : "Slett merke",
    "Set tag" : "Sett merkelapp",
    "Unset tag" : "Opphev merkelapp",
    "Tag name is a hidden system tag" : "Tagnavn er en skjult systemtag",
    "Tag already exists" : "Merkelappen finnes allerede",
    "Tag name cannot be empty" : "Navn for merkelapp kan ikke være tom",
    "An error occurred, unable to create the tag." : "Det oppsto en feil, kan ikke opprette taggen.",
    "Add default tags" : "Legg til standardtags",
    "Add tag" : "Legg til merkelapp",
    "Saving tag …" : "Lagrer tag …",
    "Task created" : "Oppgave opprettet",
    "Could not create task" : "Kunne ikke opprette oppgave",
    "No calendars with task list support" : "Ingen kalendere med støtte for oppgavelister",
    "Summarizing thread failed." : "Sammendrag av tråd feilet",
    "Could not load your message thread" : "Kunne ikke laste meldingstråden din",
    "The thread doesn't exist or has been deleted" : "Tråden finnes ikke eller er slettet",
    "Print" : "Skriv ut",
    "Loading thread" : "Laster tråd",
    "Not found" : "Ikke funnet",
    "Encrypted & verified " : "Kryptert og verifisert",
    "Signature verified" : "Signatur verifisert",
    "Signature unverified " : "Signatur ikke verifisert",
    "This message was encrypted by the sender before it was sent." : "Denne meldingen ble kryptert av avsenderen før den ble sendt.",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Denne meldingen inneholder en bekreftet digital S/MIME-signatur. Meldingen ble ikke endret siden den ble sendt.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Denne meldingen inneholder en ubekreftet digital S/MIME-signatur. Meldingen kan ha blitt endret siden den ble sendt, eller sertifikatet til signataren er ikke klarert.",
    "Reply all" : "Svar alle",
    "Unsubscribe request sent" : "Avmeldingsforespørsel sendt",
    "Could not unsubscribe from mailing list" : "Kunne ikke melde deg av e-postlisten",
    "Disable reminder" : "Deaktiver påminnelse",
    "Unsubscribe" : "Avslutt abonnement",
    "Reply to sender only" : "Svar kun til avsender",
    "Mark as unfavorite" : "Merk som ufavoritt",
    "Mark as favorite" : "Merk som favoritt",
    "Unsubscribe via link" : "Avslutt abonnement via kobling",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "Hvis du avslutter abonnementet, stoppes alle meldinger fra adresselisten {avsender}",
    "Send unsubscribe email" : "Send e-post for avmelding",
    "Unsubscribe via email" : "Avmeld via e-post",
    "{name} Assistant" : "{name} Assistent",
    "Thread summary" : "Trådsammendrag",
    "Go to latest message" : "Gå til seneste melding",
    "The message could not be translated" : "Meldingen kan ikke oversettes",
    "Translation copied to clipboard" : "Oversettelsen kopier til utklippstavlen",
    "Translation could not be copied" : "Oversettelsen kunne ikke kopieres",
    "Translate message" : "Oversett melding",
    "Source language to translate from" : "Kildespråk å oversette fra",
    "Translate from" : "Oversett fra",
    "Target language to translate into" : "Målspråk å oversette til",
    "Translate to" : "Oversett til",
    "Translating" : "Oversetter",
    "Copy translated text" : "Kopier oversatt tekst",
    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Deaktiver oppbevaring av søppelpost ved å la feltet stå tomt eller sette det til 0. Bare e-poster slettet etter at søppeloppbevaring er aktivert vil bli behandlet.",
    "Could not remove trusted sender {sender}" : "Kunne ikke fjerne pålitelig avsender {sender}",
    "No senders are trusted at the moment." : "Ingen avsendere er klarert for øyeblikket.",
    "Untitled event" : "Hendelse uten tittel",
    "(organizer)" : "(organisator)",
    "Import into {calendar}" : "Importer til {calender}",
    "Event imported into {calendar}" : "Hendelse importert til {calender}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Fly {flightNr} fra {depAirport} til {arrAirport}",
    "Airplane" : "Fly",
    "Reservation {id}" : "Reservasjon {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} fra {depStation} til {arrStation}\n ",
    "Train from {depStation} to {arrStation}" : "Tog fra {depStation} til {arrStation}\n ",
    "Train" : "Tog",
    "Stop" : "Stoppe",
    "Recipient" : "Mottaker",
    "Delete filter" : "Slett filter",
    "Help" : "Hjelp",
    "contains" : "inneholder",
    "matches" : "passer",
    "Actions" : "Handlinger",
    "Priority" : "Prioritet",
    "delete" : "slett",
    "Edit" : "Rediger",
    "Successfully updated config for \"{domain}\"" : "Vellykket oppdatert konfigurasjon for «{domain}»",
    "Error saving config" : "Feil ved lagring av konfigurasjon",
    "Saved config for \"{domain}\"" : "Lagret konfigurasjon for «{domain}»",
    "Could not save provisioning setting" : "Kunne ikke lagre klargjørings innstillingen",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Klargjort {count} konto.","Klargjort {count} kontoer."],
    "There was an error when provisioning accounts." : "Det oppsto en feil under klargjøring av kontoene.",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Vellykket slettet og deaktivert kontoer for «{domain}»",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Feil ved sletting og deaktivering av kontoer for «{domain}»",
    "Could not save default classification setting" : "Kan ikke lagre standard klassifiseringsinnstilling",
    "Mail app" : "E-post app",
    "The mail app allows users to read mails on their IMAP accounts." : "E-post appen lar brukere lese e-poster på IMAP-kontoene sine.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Her kan du finne innstillinger for hele instansen. Bruker spesifikke innstillinger finner du i selve appen (nederst til venstre).",
    "Account provisioning" : "Konto klargjøring",
    "A provisioning configuration will provision all accounts with a matching email address." : "En klargjørings konfigurasjon vil klargjøre alle kontoer med en matchende e-postadresse.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Bruk av jokertegnet (*) i klargjøringsdomenefeltet vil opprette en konfigurasjon som gjelder for alle brukere, forutsatt at de ikke samsvarer med en annen konfigurasjon.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Klargjørings mekanismen vil prioritere spesifikke domene konfigurasjoner over jokertegnet-domene konfigurasjonen.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Skulle en ny samsvarende konfigurasjon bli funnet etter at brukeren allerede var klargjort med en annen konfigurasjon, vil den nye konfigurasjonen ha forrang, og brukeren vil bli tilordnet på nytt med konfigurasjonen.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "Det kan bare være én konfigurasjon per domene og kun én domene konfigurasjon med jokertegn.",
    "These settings can be used in conjunction with each other." : "Disse innstillingene kan brukes sammen med hverandre.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "Hvis du bare vil klargjøre ett domene for alle brukere, bruk jokertegnet (*).",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Denne innstillingen gir bare mening hvis den bruker samme bruker backend for Nextcloud og e-postserveren til organisasjonen din.",
    "Provisioning Configurations" : "Klargjørings konfigurasjoner",
    "Add new config" : "Legg til ny konfig",
    "Provision all accounts" : "Klargjør alle kontoer",
    "Allow additional mail accounts" : "Tillat flere e-postkontoer",
    "Allow additional Mail accounts from User Settings" : "Tillat flere e-postkontoer fra brukerinnstillinger",
    "Enable text processing through LLMs" : "Aktiver tekstprosessering gjennom LLM-er",
    "The Mail app can process user data with the help of the configured large language model and provide assistance features like thread summaries, smart replies and event agendas." : "Mail-appen kan behandle brukerdata ved hjelp av den konfigurerte store språkmodellen og gi assistansefunksjoner som trådsammendrag, smarte svar og hendelsesagendaer.",
    "Enable LLM processing" : "Aktiver LLM-prosessering",
    "Enable classification by importance by default" : "Aktiver klassifisering etter viktighet som standard",
    "The Mail app can classify incoming emails by importance using machine learning. This feature is enabled by default but can be disabled by default here. Individual users will still be able to toggle the feature for their accounts." : "E-post-appen kan klassifisere innkommende e-post etter viktighet ved hjelp av maskinlæring. Denne funksjonen er aktivert som standard, men kan deaktiveres som standard her. Enkeltbrukere vil fortsatt kunne veksle mellom funksjonen for kontoene sine.",
    "Enable classification of important mails by default" : "Aktiver klassifisering etter viktige e-poster som standard",
    "Anti Spam Service" : "Anti spam tjeneste",
    "You can set up an anti spam service email address here." : "Du kan sette opp en e-postadresse for antispamtjeneste her.",
    "Any email that is marked as spam will be sent to the anti spam service." : "Enhver e-post som er merket som spam vil bli sendt til anti spam-tjenesten.",
    "Gmail integration" : "Gmail-integrering",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail lar brukere få tilgang til e-posten sin via IMAP. Av sikkerhetsgrunner er denne tilgangen bare mulig med en OAuth 2.0-tilkobling eller Google-kontoer som bruker tofaktorautentisering og app-passord.",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Du må registrere en ny klient-ID for en \"nettapplikasjon\" i Google Cloud-konsollen. Legg til URL-adressen {url} som autorisert omdirigerings-URI.",
    "Microsoft integration" : "Microsoft-integrering",
    "Successfully set up anti spam email addresses" : "Konfigurer anti spam e-postadresser",
    "Error saving anti spam email addresses" : "Feil ved lagring av anti spam-e-postadresser",
    "Successfully deleted anti spam reporting email" : "Vellykket slettet  anti spam rapportering e-post",
    "Error deleting anti spam reporting email" : "Feil ved sletting av anti spam rapporterings e-post",
    "Anti Spam" : "Anti Spam",
    "Add the email address of your anti spam report service here." : "Legg til e-postadressen til din anti spam-rapporttjeneste her.",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Når du bruker denne innstillingen, vil en rapport-e-post bli sendt til SPAM-rapport serveren når en bruker klikker \"Merk som spam\".",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Den opprinnelige meldingen vil legges ved som et \"melding/rfc822\"-vedlegg.",
    "\"Mark as Spam\" Email Address" : "\"Merk som spam\" e-postadresse",
    "\"Mark Not Junk\" Email Address" : "\"Merk ikke søppelpost\" e-postadresse",
    "Reset" : "Tilbakestill",
    "Google integration configured" : "Google-integrasjon konfigurert",
    "Could not configure Google integration" : "Kunne ikke konfigurere Google-integrasjon",
    "Google integration unlinked" : "Google-integrasjon koblet fra",
    "Could not unlink Google integration" : "Kunne ikke koble fra Google-integrasjonen",
    "Client ID" : "Klient-ID",
    "Client secret" : "Klient-hemmelighet",
    "Unlink" : "Fjern koblingen",
    "Microsoft integration configured" : "Microsoft-integrasjon konfigurert",
    "Could not configure Microsoft integration" : "Kunne ikke konfigurere Microsoft-integrasjon",
    "Microsoft integration unlinked" : "Microsoft-integrasjon koblet fra",
    "Could not unlink Microsoft integration" : "Kunne ikke koble fra Microsoft-integrasjon",
    "Tenant ID (optional)" : "Leier-ID (valgfritt)",
    "Domain Match: {provisioningDomain}" : "Domenematch: {provisioningDomain}",
    "Email: {email}" : "E-post: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} på {host}:{port} ({ssl}-kryptering)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} på {host}:{port} ({ssl}-kryptering)",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve:  {user} på {host}:{port} ({ssl}-kryptering)",
    "Configuration for \"{provisioningDomain}\"" : "Konfigurasjon for «{provisioningDomain}»",
    "Provisioning domain" : "Klargjør domene",
    "Email address template" : "E-postadresse mal",
    "IMAP" : "IMAP",
    "User" : "Bruker",
    "Host" : "Server",
    "Port" : "Port",
    "SMTP" : "SMTP",
    "Master password" : "Hovedpassord",
    "Use master password" : "Bruk hovedpassord",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "Aktiver sieve integrasjon",
    "LDAP aliases integration" : "Integrasjon av LDAP-aliaser",
    "Enable LDAP aliases integration" : "Aktiver integrasjon av LDAP-aliaser",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP alias-integrasjonen leser et attributt fra den konfigurerte LDAP-katalogen for å klargjøre e-post aliaser.",
    "LDAP attribute for aliases" : "LDAP attributt for aliaser",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Et attributt med flere verdier for klargjøring av e-post aliaser. For hver verdi opprettes et alias. Aliaser som eksisterer i Nextcloud som ikke er i LDAP katalogen, slettes.",
    "Save Config" : "Lagre konfigurasjon",
    "Unprovision & Delete Config" : "Opphev tilordning og slett konfigurasjon",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% og %E MAIL% vil bli erstattet med brukerens UID og e-post",
    "With the settings above, the app will create account settings in the following way:" : "Med innstillingene ovenfor vil appen opprette konto innstillinger på følgende måte:",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Det angitte PKCS #12-sertifikatet må inneholde minst ett sertifikat og nøyaktig én privat nøkkel.",
    "Failed to import the certificate. Please check the password." : "Kunne ikke importere sertifikatet. Vennligst sjekk passordet.",
    "Certificate imported successfully" : "Sertifikatet ble importert",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Kan ikke importere sertifikatet. Forsikre deg om at den private nøkkelen samsvarer med sertifikatet og ikke er beskyttet av en passordfrase.",
    "Failed to import the certificate" : "Kunne ikke importere sertifikatet",
    "S/MIME certificates" : "S/MIME-sertifikater",
    "Certificate name" : "Sertifikatnavn",
    "E-mail address" : "E-postadresse",
    "Valid until" : "Gyldig til",
    "Delete certificate" : "Slett sertifikat",
    "No certificate imported yet" : "Ingen sertifikat importert enda",
    "Import certificate" : "Importer sertifikat",
    "Import S/MIME certificate" : "Importer S/MIME-sertifikat",
    "PKCS #12 Certificate" : "PKCS #12-sertifikat",
    "PEM Certificate" : "PEM-sertifikat",
    "Certificate" : "Sertifikat",
    "Private key (optional)" : "Privat nøkkel (valgfritt)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Den private nøkkelen er bare nødvendig hvis du har tenkt å sende signerte og krypterte e-postmeldinger ved hjelp av dette sertifikatet.",
    "Submit" : "Send inn",
    "Group" : "Gruppe",
    "Shared" : "Delt",
    "Shares" : "Delinger",
    "Insert" : "Sett inn",
    "Account connected" : "Konto er koblet",
    "You can close this window" : "Du kan lukke dette vinduet",
    "Connect your mail account" : "Koble til din e-postkonto",
    "To add a mail account, please contact your administrator." : "For å legge til en e-postkonto, vennligst kontakt administratoren.",
    "All" : "Alle",
    "Drafts" : "Kladder",
    "Favorites" : "Favoritter",
    "Priority inbox" : "Prioritert innboks",
    "All inboxes" : "Alle innbokser",
    "Inbox" : "Innboks",
    "Junk" : "Søppel",
    "Sent" : "Sendt",
    "Trash" : "Papirkurv",
    "Connect OAUTH2 account" : "Koble OAUTH2-konto",
    "Error while sharing file" : "Feil under deling av fil",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny melding \nfra {from}","%n nye meldinger \nfra {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "Det er allerede en melding på gang. Alle ulagrede endringer vil gå tapt hvis du fortsetter!",
    "Discard changes" : "Forkast endringer",
    "Discard unsaved changes" : "Forkast ulagrede endringer",
    "Keep editing message" : "Fortsett å redigere melding",
    "Attachments were not copied. Please add them manually." : "Vedlegg ble ikke kopiert. Vennligst legg dem til manuelt.",
    "Could not create snooze mailbox" : "Kan ikke opprette slumrepostboks",
    "Message sent" : "Melding sendt",
    "Could not send message" : "Kunne ikke sende melding",
    "Could not load {tag}{name}{endtag}" : "Kunne ikke laste {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Det oppsto et problem under lasting av {tag}{name}{endtag}",
    "Could not load your message" : "Kunne ikke laste meldingene dine",
    "Could not load the desired message" : "Kunne ikke laste den ønskede meldingen",
    "Could not load the message" : "Kunne ikke laste meldingen",
    "Error loading message" : "Feil ved innlasting av melding",
    "Forwarding to %s" : "Videresender til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikk her hvis du ikke blir videresendt automatisk innen få sekunder.",
    "Redirect" : "Videresend",
    "The link leads to %s" : "Denne lenken leder til %s",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke vil besøke den siden, kan du gå tilbake til <a href=\"%s\">E-post</a>",
    "Continue to %s" : "Fortsett til %s",
    "Search in the body of messages in priority Inbox" : "Søke i meldingsteksten i prioritert innboks",
    "Put my text to the bottom of a reply instead of on top of it." : "Legg teksten min nederst i et svar i stedet for på toppen av det.",
    "Use internal addresses" : "Bruk interne adresser",
    "Accounts" : "Kontoer",
    "Newest" : "Nyeste",
    "Oldest" : "Eldst",
    "Reply text position" : "Svartekstposisjon",
    "Use Gravatar and favicon avatars" : "Bruk Gravatar- og favikon-avatarer",
    "Register as application for mail links" : "Registrer som applikasjon for e-postlenker",
    "Data collection consent" : "Samtykke til innsamling av data",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Tillat at appen samler inn data om interaksjonene dine. Basert på disse dataene vil appen tilpasse seg dine preferanser. Dataene vil kun bli lagret lokalt.",
    "Trusted senders" : "Pålitelige avsendere",
    "Internal addresses" : "Interne adresser",
    "Manage S/MIME certificates" : "Administrer S/MIME-sertifikater"
},
"nplurals=2; plural=(n != 1);");
